"""Auto-generated terminal name aliases."""
# Auto-generated by codegen_terminfo.py
# Maps alternative terminal names to the primary ncurses name.
# Primary names are module names (with '-' and '.' replaced by '_').

ALIASES = {
    'X-hpterm': 'hpterm',
    'ansi80x25': 'cons25',
    'ansis': 'cons25',
    'contour-latest': 'contour',
    'iris-ansi-net': 'iris-ansi',
    'iterm2': 'iTerm2.app',
    'rxvt-color': 'rxvt',
    'stterm': 'st',
    'stterm-256color': 'st-256color',
    'sun1': 'sun',
    'sun2': 'sun',
    'vt100-am': 'vt100',
    'vt200': 'vt220',
    'vt300': 'vt320',
    'wyse50': 'wy50',
    'xterm-ghostty': 'ghostty',
    'xterm-kitty': 'kitty',
}
